---
title: 'PyGEE-SWToolbox: A Python Jupyter Notebook toolbox for interactive surface water mapping and analysis using Google Earth Engine'
tags:
  - Python
  - Google Earth Engine
  - Jupyter Notebook
  - surface water mapping
  - geemap
authors:
  - name: Collins Owusu
    orcid: 0000-0001-6754-9311
    affiliation: "1,2"
  - name: Nusrat J. Snigdha
    orcid: 0000-0002-9444-1469
    affiliation: "1,2"
  - name: Mackenzie T. Martin
    orcid: 0000-0002-7744-2080
    affiliation: "1,2"
  - name: Alfred J. Kalyanapu
    orcid: 0000-0002-7746-3121
    affiliation: "1,2"
affiliations:
 - name: Department of Civil and Environmental Engineering, Tennessee Technological University <br>
   index: 1
   
 - name: Water Center, Tennessee Technological University
   index: 2
date: 29 June 2021
bibliography: paper.bib
---

# Summary

PyGEE-SWToolbox is Python-Google Earth Engine (GEE) [@gorelick2017google] Surface Water Analysis toolbox 
developed in Jupyter Notebook for interactive surface water mapping and analysis using the GEE cloud computing platform. 
This toolbox provides a graphical user interface (GUI) for satellite imagery retrieval, surface water extraction, water occurrence frequency 
analysis, water depth estimation, time series analysis, and visualization using the GEE platform without the user writing a single 
line of JavaScript or Python code. Satellite imagery retrieved by the toolbox together with spatial datasets generated by the toolbox can be exported 
for use in other mapping environments. The GUI was developed with Python 3 in Jupyter Notebook using ipyleaflet and ipywidgets. 
The toolbox relies on the <b>GEE Python API, geemap [@Wu2020], geetools, eemont [@Montero2021], hydra-floods, Numpy, pandas, 
and plotly</b> Python packages. The toolbox together with a user manual provides users an easy way to analyze and visualize GEE 
datasets for water resource applications.


# Statement of need

The GEE platform has been applied in various aspects of water resource monitoring such as wetland inundation 
dynamics [@Wu2019], flood monitoring [@DeVries2020], satellite-derived bathymetry [@Casal2020], and 
gap-filling of time series [@Walker2020]. Conventional use of the GEE platform requires the user to 
able to write JavaScript codes in the GEE online Code Editor or the use of Python codes using the GEE Python 
API to perform geospatial processing of datasets. This is sometimes problematic for some researchers and 
water resource managers with limited knowledge in programming or who are new to the programming languages needed to 
communicate with the GEE platform. This toolbox provides a simple GUI as a solution to some of the challenges 
faced by non-programmers in utilizing the GEE platform for water resources monitoring.

# Audience

The toolbox is intended for researchers, water resource managers, planners, and students who would 
like to utilize the geospatial datasets and cloud computing power of the GEE platform to 
monitor changes in water resources with little to no knowledge on the use of the platform and its 
coding requirements. The toolbox is currently being used by a team of researchers from the civil engineering and biology departments 
at Tennessee Technological University in monitoring the hydrology of wetlands under the Wetland Reserve Program (WRP) which are being monitored 
to assess the effectiveness of wetland restoration practices implemented by the Natural Resources 
Conservation Service (NRCS) and The Nature Conservancy (TNC) in West Tennessee and West Kentucky.

# Functionality

PyGEE-SWToolbox can:

- Retrieve time series of Landsat, Sentinel-1, Sentinel-2, and National Agriculture Imagery Program (NAIP) satellite imagery for a study area.

- Extract surface water from all retrieved satellite imagery using water extraction indices such as NDWI [@McFEETERS1996], MNDWI [@Xu2006], AWEI [@FEYISA201423], and DSWE [@Walker2020].

- Generate a time-series of surface water area dynamics and export times-eries to CSV format.

- Perform water occurence frequency and hydroperiod analysis.

- Estimate water depth using surface water extent and digital elevation models (DEMs).

- Visualize satellite data, water and depth maps, and time-series of water dynamics.

- Export retrieved satellite imagery, surface water, and frequency maps to Google Drive or download them to the user's local computer for use in other GIS environments.



# Acknowledgements

This toolbox is based upon work supported by the Natural Resources Conservation Service, 
U.S. Department of Agriculture, and The Nature Conservancy, under award number 
68-5C16-17-015. Any opinions, findings, conclusions, or recommendations 
expressed in this publication are those of the authors and do not necessarily 
reflect the views of the Natural Resources Conservation Service or The Nature Conservancy.
The authors also acknowledge the funding support from the Center for the Management, Utilization, and Protection of Water Resources (TTU Water Center) at
the Tennessee Technological University.

# References
